@@ -7,7 +7,7 @@ use MooseX::StrictConstructor;
 
 # Initialize our version
 use vars qw( $VERSION );
-$VERSION = '0.02';
+$VERSION = '0.03';
 
 # TODO improve validation for everything here, ha!
 
@@ -23,11 +23,24 @@ has 'event' => (
 	required	=> 1,
 );
 
+has 'tostr' => (
+	isa		=> 'Str',
+	is		=> 'ro',
+	lazy		=> 1,
+	default		=> sub {
+		my $self = shift;
+		return $self->line;
+	},
+);
+
 no Moose;
 __PACKAGE__->meta->make_immutable;
 
 1;
 __END__
+
+=for stopwords tostr
+
 =head1 NAME
 
 Games::AssaultCube::Log::Line::Base - The base log line object
@@ -53,6 +66,10 @@ The raw log line
 
 The event specified by the line ( see subclasses for all possible event types )
 
+=head3 tostr
+
+A convenience attribute returning a nice string representing this event ( might differ from the line! )
+
 =head1 AUTHOR
 
 Apocalypse E<lt>apocal@cpan.orgE<gt>
