@@ -6,7 +6,7 @@ use Moose;
 
 # Initialize our version
 use vars qw( $VERSION );
-$VERSION = '0.02';
+$VERSION = '0.03';
 
 extends 'Games::AssaultCube::Log::Line::Base';
 
@@ -33,6 +33,16 @@ has 'finished' => (
 	required	=> 1,
 );
 
+has 'tostr' => (
+	isa		=> 'Str',
+	is		=> 'ro',
+	lazy		=> 1,
+	default		=> sub {
+		my $self = shift;
+		return "GameStatus: map " . $self->map . " with " . $self->minutes . " minutes left in gamemode " . $self->gamemode_fullname;
+	},
+);
+
 # TODO Moose can't export multiple roles into this class unless it defines BUILD...
 # Error:  'Games::AssaultCube::Log::Line::Base::Mastermode|Games::AssaultCube::Log::Line::Base::Gamemode' requires the method 'BUILD' to be implemented by 'Games::AssaultCube::Log::Line::GameStatus' at /usr/local/share/perl/5.10.0/Moose/Meta/Role/Application.pm line 59
 sub BUILD {
@@ -44,6 +54,8 @@ __PACKAGE__->meta->make_immutable;
 
 1;
 __END__
+
+=for stopwords CTF NUM TDM gamemode mastermode
 =head1 NAME
 
 Games::AssaultCube::Log::Line::GameStatus - Describes the GameStatus event in a log line
