@@ -6,7 +6,7 @@ use Moose;
 
 # Initialize our version
 use vars qw( $VERSION );
-$VERSION = '0.02';
+$VERSION = '0.03';
 
 extends 'Games::AssaultCube::Log::Line::Base';
 
@@ -24,11 +24,23 @@ has 'success' => (
 	required	=> 1,
 );
 
+has 'tostr' => (
+	isa		=> 'Str',
+	is		=> 'ro',
+	lazy		=> 1,
+	default		=> sub {
+		my $self = shift;
+		return "Masterserver reply(" . ( $self->success ? "OK" : "FAIL" ) . "): " . $self->reply;
+	},
+);
+
 no Moose;
 __PACKAGE__->meta->make_immutable;
 
 1;
 __END__
+
+=for stopwords masterserver
 =head1 NAME
 
 Games::AssaultCube::Log::Line::MasterserverReply - Describes the MasterserverReply event in a log line
