@@ -6,7 +6,7 @@ use Moose;
 
 # Initialize our version
 use vars qw( $VERSION );
-$VERSION = '0.02';
+$VERSION = '0.03';
 
 extends 'Games::AssaultCube::Log::Line::Base';
 
@@ -32,11 +32,24 @@ has 'spam' => (
 	default		=> 0,
 );
 
+has 'tostr' => (
+	isa		=> 'Str',
+	is		=> 'ro',
+	lazy		=> 1,
+	default		=> sub {
+		my $self = shift;
+		return $self->nick . " said" . ( $self->isteam ? " to team: " : ": " ) . $self->text;
+	},
+);
+
 no Moose;
 __PACKAGE__->meta->make_immutable;
 
 1;
 __END__
+
+=for stopwords isteam ip
+
 =head1 NAME
 
 Games::AssaultCube::Log::Line::Says - Describes the Says event in a log line
